#!/bin/bash
set -ex

if [[ "$1" == apache2* ]] || [ "$1" == php-fpm ] || [ "$1" == "testmode" ]; then

  # Wait for DB Server
  if [ "$ROUNDCUBEMAIL_DB_TYPE" == "pgsql" ]; then
    /usr/local/sbin/wait-for-it.sh ${ROUNDCUBEMAIL_DB_HOST}:${ROUNDCUBEMAIL_DB_PORT:-5432} -t 30
  elif [ "$ROUNDCUBEMAIL_DB_TYPE" == "mysql" ]; then
    /usr/local/sbin/wait-for-it.sh ${ROUNDCUBEMAIL_DB_HOST}:${ROUNDCUBEMAIL_DB_PORT:-3306} -t 30
  fi

  # Create configuration if required, then init the database.
  if [ ! -e /var/roundcube/config/config.inc.php ]; then
    /usr/local/sbin/write-config.sh
    /var/www/html/bin/initdb.sh --dir=/var/www/html/SQL \
      || echo "initdb.sh failed to execute, please bash into the container and run it manually."
  fi
  /var/www/html/bin/updatedb.sh --dir=/var/www/html/SQL --package=roundcube \
    || echo "updatedb.sh failed to execute, please bash into the container and run it manually."

  # Add Filesize limits to PHP config
  if [ ! -z "${ROUNDCUBEMAIL_UPLOAD_MAX_FILESIZE}" ]; then
    echo "upload_max_filesize=${ROUNDCUBEMAIL_UPLOAD_MAX_FILESIZE}" > /usr/local/etc/php/conf.d/roundcube-filesize.ini
    echo "post_max_size=${ROUNDCUBEMAIL_UPLOAD_MAX_FILESIZE}" >> /usr/local/etc/php/conf.d/roundcube-filesize.ini
  fi

  # Move Dist config files into the volume
  cp /var/www/html/config/defaults.inc.php /var/roundcube/config/defaults.inc.php.sample
  cp /var/www/html/config/config.inc.php.sample /var/roundcube/config/
  cp /var/www/html/plugins/ispconfig3_account/config/config.inc.php.dist /var/roundcube/config/ispconfig3_account.inc.php.sample
fi

if [ "$1" == "testmode" ]; then
  exec /bin/bash
else
  exec "$@"
fi
